Enum Tamptrg
#[repr(u8)]pub enum Tamptrg {
FilteredLowOrUnfilteredHigh = 0,
FilteredHighOrUnfilteredLow = 1,
}Variants
FilteredLowOrUnfilteredHigh = 0
If TAMPFLT != 00 Tamper x input staying low triggers a tamper detection event. If TAMPFLT = 00 Tamper x input rising edge and high level triggers a tamper detection event
FilteredHighOrUnfilteredLow = 1
If TAMPFLT != 00 Tamper x input staying high triggers a tamper detection event. If TAMPFLT = 00 Tamper x input falling edge and low level triggers a tamper detection event
Implementations